@@ -20,7 +20,6 @@
 
 #include <gpe/init.h>
 #include <gpe/errorbox.h>
-#include <gpe/render.h>
 #include <gpe/pixmaps.h>
 #include <gpe/picturebutton.h>
 #include <gpe/question.h>
@@ -38,7 +37,6 @@
 
 
 #define WINDOW_NAME "IRC Client"
-#define _(_x) gettext (_x)
 
 struct gpe_icon my_icons[] = {
   {"new", "new", NULL},
@@ -170,7 +168,25 @@ update_text_view (GString * text)
 }
 
 
-void append_nick_to_buffer (IRCServer * server, gchar * target, gchar * nick)
+void append_to_buffer_printf (IRCServer * server,
+	const gchar * target, const gchar *tag_name, const gchar * format, ...)
+{
+    gchar *str = NULL;
+    va_list args;
+
+    va_start(args, format);
+    str = g_strdup_vprintf(format, args);
+    va_end(args);
+
+    append_to_buffer(server, target, str, tag_name);
+
+    g_free(str);
+}
+
+
+
+void append_nick_to_buffer (IRCServer * server,
+	const gchar * target, const gchar * nick)
 {
   gchar *tag = NULL;
   gchar *str = NULL;
@@ -194,8 +210,8 @@ void append_nick_to_buffer (IRCServer * server, gchar * target, gchar * nick)
 
 
 void
-append_to_buffer (IRCServer * server, gchar * target, gchar * text,
-                  gchar * tag_name)
+append_to_buffer (IRCServer * server, const gchar * target, const gchar * text,
+                  const gchar * tag_name)
 {
   GtkTextIter start, end;
   GtkTextBuffer *buffer = NULL;
@@ -353,7 +369,7 @@ add_default_buffer_tags (GtkTextBuffer * buffer)
 }
 
 void
-join_channel (IRCServer * server, gchar * channel_name)
+join_channel (IRCServer * server, const gchar * channel_name)
 {
   IRCChannel *channel;
   GtkWidget *button;
@@ -551,8 +567,6 @@ new_connection_dialog ()
   GtkWidget *network_combo, *server_combo, *nick_entry, *real_name_entry,
     *password_entry;
   GtkWidget *connect_button, *close_button, *network_properties_button;
-  GdkPixmap *pmap;
-  GdkBitmap *bmap;
 
   GHashTable *network_hash;
   network_hash = g_hash_table_new (g_str_hash, g_str_equal);
@@ -661,8 +675,7 @@ new_connection_dialog ()
   gtk_table_attach_defaults (GTK_TABLE (table), real_name_entry, 1, 2, 3, 4);
   gtk_table_attach_defaults (GTK_TABLE (table), password_entry, 1, 2, 4, 5);
 
-  if (gpe_find_icon_pixmap ("globe", &pmap, &bmap))
-    gdk_window_set_icon (window->window, NULL, pmap, bmap);
+  gpe_set_window_icon (window, "globe");
 
   get_networks (network_combo, network_hash);
 
@@ -689,8 +702,6 @@ join_channel_dialog ()
 {
   GtkWidget *window, *vbox, *hbox, *button_hbox, *label, *hsep, *entry;
   GtkWidget *join_button, *close_button;
-  GdkPixmap *pmap;
-  GdkBitmap *bmap;
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (window), "IRC Client - Join Channel");
@@ -734,8 +745,7 @@ join_channel_dialog ()
   gtk_box_pack_end (GTK_BOX (button_hbox), close_button, FALSE, FALSE, 0);
   gtk_box_pack_end (GTK_BOX (button_hbox), join_button, FALSE, FALSE, 0);
 
-  if (gpe_find_icon_pixmap ("globe", &pmap, &bmap))
-    gdk_window_set_icon (window->window, NULL, pmap, bmap);
+  gpe_set_window_icon (window, "globe");
 
   gtk_widget_show_all (window);
 }
@@ -881,8 +891,7 @@ main (int argc, char *argv[])
   menu_item = gtk_image_menu_item_new_with_label ("New Connection");
   g_signal_connect (GTK_OBJECT (menu_item), "activate",
                     G_CALLBACK (new_connection_dialog), NULL);
-  menu_item_image =
-    gpe_render_icon (menu_item->style, gpe_find_icon ("globe"));
+  menu_item_image = gtk_image_new_from_pixbuf(gpe_find_icon ("globe"));
   gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item),
                                  menu_item_image);
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
